<?php

namespace Drupal\social_auth_enforcer\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure social_auth_enforcer settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'social_auth_enforcer_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['social_auth_enforcer.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['enforced'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Email Regex Patterns to Enforce'),
      '#description' => $this->t('Enter the regex patterns to match which users to force logins via social authentication. One per line.<br>Example: <code>\@gmail\.com$</code>'),
      '#default_value' => $this->config('social_auth_enforcer.settings')->get('enforced'),
    ];

    $form['error_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Error message'),
      '#description' => $this->t('The error that should be displayed to user in case of attempt to login using an account restricted to login only via social auth.'),
      '#default_value' => $this->config('social_auth_enforcer.settings')->get('error_message'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('social_auth_enforcer.settings')
      ->set('enforced', $form_state->getValue('enforced'))
      ->set('error_message', $form_state->getValue('error_message'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
